@@ -862,15 +862,15 @@ bool DatabaseManager::insertTarget(Target* target)
 	return ret;
 }
 
-QList<Target*> DatabaseManager::getTargets(const QString & filter)
+QList<Target*> DatabaseManager::getTargets(const QString * filter)
 {
 	QList<Target*> result;
 
 	QSqlQuery query (db);
 	bool ret;
-	if (filter != NULL && filter.length() > 0) {
-		ret = query.prepare("select id, name, type, groupName from targets where groupName = :groupName");
-		query.bindValue(":groupName", filter);
+	if (filter != NULL) {// && filter.length() > 0) {
+		ret = query.prepare("select id, name, type, groupName from targets where coalesce(groupName,'') = :groupName");
+		query.bindValue(":groupName", *filter);
 	}
 	else {
 		ret = query.prepare("select id, name, type, groupName from targets");
@@ -897,9 +897,14 @@ QList<QString> DatabaseManager::getGroups()
 {
 	QList<QString> result;
 
-	QSqlQuery query("select distinct coalesce(groupName,'') from targets where groupName != '' and groupName is Not Null order by groupName", db);
+	//QSqlQuery query("select distinct coalesce(groupName,'') from targets where groupName != '' and groupName is Not Null order by groupName", db);
+	QSqlQuery query("select distinct coalesce(groupName,'') from targets order by coalesce(groupName,'')", db);
 	while (query.next()) {
-		result.append(query.value(0).toString());
+		QString name = query.value(0).toString();
+
+		//qDebug () << "ADDING GROUP " << name;
+
+		result.append(name);
 	}
 
 	return result;
@@ -1210,7 +1215,7 @@ bool DatabaseManager::renameGroup (const QString & from, const QString & to) {
 	bool ret = false;
 	if (db.isOpen()) {
 		QSqlQuery query (db);
-		ret = query.prepare("UPDATE targets set groupName = :newGroupName WHERE groupName = :oldGroupName");
+		ret = query.prepare("UPDATE targets set groupName = :newGroupName WHERE coalesce(groupName,'') = :oldGroupName");
 		if (ret) {
 			query.bindValue(":newGroupName", to);
 			query.bindValue(":oldGroupName", from);
@@ -1224,7 +1229,7 @@ bool DatabaseManager::deleteGroup (const QString & from) {
 	bool ret = false;
 	if (db.isOpen()) {
 		QSqlQuery query (db);
-		ret = query.prepare("UPDATE targets set groupName = '' WHERE groupName = :oldGroupName");
+		ret = query.prepare("UPDATE targets set groupName = '' WHERE coalesce(groupName,'') = :oldGroupName");
 		if (ret) {
 			query.bindValue(":oldGroupName", from);
 			ret = query.exec ();
