@@ -102,7 +102,7 @@ public:
 	int nextId();
 
 	bool insertTarget(Target* target);
-	QList<Target*> getTargets(const QString & filter);
+	QList<Target*> getTargets(const QString * filter);
 	QList<QString> getGroups ();
 
 	bool deleteTarget(Target* target);
