@@ -94,7 +94,7 @@ RenameGroupDialog::~RenameGroupDialog() {
 }
 
 
-eWallet::eWallet(QString group, eWallet * _parent, QWidget *parent) : QMainWindow(parent)
+eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) : QMainWindow(parent)
 {
 	isFirst = false;
 	types = _parent->types;
@@ -121,7 +121,7 @@ eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 {
 
 	isFirst = true;
-	currentGroup = "";
+	currentGroup = NULL;
 	centralWidget = NULL;
 	isShowGroups = 0;
 
@@ -194,6 +194,8 @@ void eWallet::showList () {
 	hideSearch = new QPushButton(QIcon(":/resources/icon_hide.png"), "", this);
 
 	inputWidget->addWidget(cancelSearch);
+	searchField->setText(currentFilter);
+	searchField->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 	inputWidget->addWidget(searchField);
 	inputWidget->addWidget(hideSearch);
 
@@ -204,10 +206,6 @@ void eWallet::showList () {
 	QObject::connect(hideSearch, SIGNAL(clicked()), this, SLOT(_hideSearch()));
 	QObject::connect(searchField, SIGNAL(textChanged(const QString &)), this, SLOT(textChanged(const QString &)));
 
-	cancelSearch->hide ();
-	searchField->hide ();
-	hideSearch->hide ();
-
 	centralWidget->setLayout(vboxlayout);
 
 	createMenu ();
@@ -217,6 +215,21 @@ void eWallet::showList () {
 
 	////qDebug () << "setFocus()";
 	centralWidget->setFocus ();
+	//fnListWidget->setFocus ();
+
+	if (currentFilter.length () > 0) {
+		cancelSearch->show ();
+		searchField->show ();
+		//setFocus ();
+		//focusNextChild();
+		searchField->setFocus();
+		hideSearch->show ();
+	}
+	else {
+		cancelSearch->hide ();
+		searchField->hide ();
+		hideSearch->hide ();
+	}
 }
 
 void eWallet::_clickBack () {
@@ -273,15 +286,16 @@ void eWallet::selectItem(QListWidgetItem * item) {
 			fnListWidget->setCurrentItem(item);
 		}
 
-		QString target;
+		QString *_target;
 
-		if (fnListWidget->currentRow() > 0)
-			target = grouplist.at(fnListWidget->currentRow() - 1);
+		if (fnListWidget->currentRow() > 0) {
+			_target = new QString (grouplist.at(fnListWidget->currentRow() - 1));
+		}
 		else
-			target = "";
+			_target = NULL;
 
 		if (extraWindow.isNull()) {
-			extraWindow = new eWallet(target, this, this);
+			extraWindow = new eWallet(_target, this, this);
 			//extraWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
 			extraWindow->setAttribute(Qt::WA_DeleteOnClose);
 	        connect(extraWindow, SIGNAL(destroyed(QObject*)),
@@ -346,18 +360,41 @@ void eWallet::textChanged (const QString & text) {
 
 void eWallet::filterBy (const QString & s) {
 	if (isShowGroups == 1) {
-		for (int i = 0; i < grouplist.size (); i++) {
-			QString target = grouplist.at(i);
+		bool isIncluded = false;
 
-			if (s.length() == 0) {
-				fnListWidget->item(i)->setHidden(false);
+		isIncluded = tr("<All>").contains(s, Qt::CaseInsensitive);
+		if (s.length() == 0) {
+			fnListWidget->item(0)->setHidden(false);
+		}
+		else {
+			if (isIncluded) {
+				fnListWidget->item(0)->setHidden(false);
 			}
 			else {
-				if (target.contains(s, Qt::CaseInsensitive)) {
-					fnListWidget->item(i)->setHidden(false);
+				fnListWidget->item(0)->setHidden(true);
+			}
+		}
+
+		for (int i = 0; i < grouplist.size (); i++) {
+			if (i > 0 || (i == 0 && grouplist.at(0).length () > 0)) {
+				QString target = grouplist.at(i);
+				isIncluded = target.contains(s, Qt::CaseInsensitive);
+			}
+			else {
+				isIncluded = tr("<No Group>").contains(s, Qt::CaseInsensitive);
+			}
+			//qDebug () << " GROUP 4 " << i;
+
+			////qDebug () << "cc GROUP " << i;
+			if (s.length() == 0) {
+				fnListWidget->item(i+1)->setHidden(false);
+			}
+			else {
+				if (isIncluded) {
+					fnListWidget->item(i+1)->setHidden(false);
 				}
 				else {
-					fnListWidget->item(i)->setHidden(true);
+					fnListWidget->item(i+1)->setHidden(true);
 				}
 			}
 		}
@@ -440,10 +477,21 @@ bool eWallet::openDataBase (const QString & pas)
 			grouplist.clear ();
 			grouplist = ::dbManager->getGroups ();
 
-			if (grouplist.size() >= 1)
+			if (grouplist.size() > 1) {
 				isShowGroups = 1;
+			}
 			else
+			if (grouplist.size() == 1) {
+				if (grouplist.at(0).length() == 0) {
+					isShowGroups = 2;
+				}
+				else {
+					isShowGroups = 1;
+				}
+			}
+			else {
 				isShowGroups = 2;
+			}
 		}
 
 		showList ();
@@ -454,6 +502,8 @@ bool eWallet::openDataBase (const QString & pas)
 
 eWallet::~eWallet ()
 {
+	if (currentGroup != NULL)
+		delete currentGroup;
 	//delete ::dbManager;
 }
 
@@ -545,7 +595,7 @@ void eWallet::loadTypesAndFields () {
 }
 
 void eWallet::keyPressEvent(QKeyEvent* event) {
-	qDebug()<<"key pressed " << event->key();
+	//qDebug()<<"key pressed " << event->key();
 	
 	if (!isAskPassword) {
 		if (searchField->isHidden()) {
@@ -638,12 +688,18 @@ void eWallet::showGroups(bool reset)
 	for (int i = 0; i < grouplist.size (); i++) {
 		QString target = grouplist.at(i);
 
-		QListWidgetItem* listitem = new QListWidgetItem(target, fnListWidget);
+		QListWidgetItem * listitem;
+		if (target.length() == 0) {
+			listitem = new QListWidgetItem(tr("<No Group>"), fnListWidget);
+		}
+		else {
+			listitem = new QListWidgetItem(target, fnListWidget);
+		}
 		//listitem->set(target->getSummary());
 		fnListWidget->addItem(listitem);
 	}
 
-	//filterBy(currentFilter);
+	filterBy(currentFilter);
 
 	if (current >= 0 && current <= grouplist.size ())
 		fnListWidget->setCurrentRow(current);
@@ -663,7 +719,7 @@ void eWallet::showInfo(bool reset) {
 	}
 }
 
-void eWallet::showTargets(bool reset, const QString & filter)
+void eWallet::showTargets(bool reset, const QString * filter)
 {
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 
@@ -698,7 +754,10 @@ void eWallet::showTargets(bool reset, const QString & filter)
 
 	filterBy(currentFilter);
 
-	fnListWidget->setCurrentRow(0);
+	if (current >= 0 && current <= list.size ())
+		fnListWidget->setCurrentRow(current);
+	else
+		fnListWidget->setCurrentRow(0);
 
 	update();
 
@@ -900,8 +959,10 @@ void eWallet::windowDestroyedEdit(QObject* obj)
 		grouplist = ::dbManager->getGroups ();
 
 		if (grouplist.size() >= 1 && isFirst) {
-			isShowGroups = 1;
-			showGroups(true);
+			if (grouplist.size() > 1 || grouplist.at(0).length() > 0) {
+				isShowGroups = 1;
+				showGroups(true);
+			}
 		}
 	}
 
@@ -1126,7 +1187,21 @@ void eWallet::renameGroup () {
 		delete dialog;
 
 		if (::dbManager->renameGroup(target, newName)) {
-			showGroups(true);
+			grouplist.clear ();
+			grouplist = ::dbManager->getGroups ();
+
+			if (grouplist.size() > 1) {
+				showGroups(false);
+			}
+			else {
+				if (grouplist.size() == 1 && grouplist.at(0).length () > 0) {
+					showGroups(false);
+				}
+				else {
+					isShowGroups = 2;
+					showTargets(true, NULL);
+				}
+			}
 		}
 
 	}
@@ -1137,12 +1212,20 @@ void eWallet::deleteGroup () {
 		QString target = grouplist.at(fnListWidget->currentRow() - 1);
 
 		if (::dbManager->deleteGroup(target)) {
+			grouplist.clear ();
+			grouplist = ::dbManager->getGroups ();
+
 			if (grouplist.size() > 1) {
-				showInfo(true);
+				showGroups(false);
 			}
 			else {
-				isShowGroups = 2;
-				showTargets(true, "");
+				if (grouplist.size() == 1 && grouplist.at(0).length () > 0) {
+					showGroups(false);
+				}
+				else {
+					isShowGroups = 2;
+					showTargets(true, NULL);
+				}
 			}
 		}
 
@@ -1296,7 +1379,7 @@ void eWallet::duplicateTarget (Target * target) {
 	dbManager->getFields(target);
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(target, currentGroup, 2, true, this, this);
+		detailWindowEdit = new DetailWindow(target, *currentGroup, 2, true, this, this);
 		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
@@ -1309,7 +1392,7 @@ void eWallet::newLikeTarget (Target * target) {
 	dbManager->getFields(target);
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(target, currentGroup, 1, true, this, this);
+		detailWindowEdit = new DetailWindow(target, *currentGroup, 1, true, this, this);
 		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
@@ -1320,7 +1403,7 @@ void eWallet::newLikeTarget (Target * target) {
 
 void eWallet::newTarget() {
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(NULL, currentGroup, 0, true, this, this);
+		detailWindowEdit = new DetailWindow(NULL, *currentGroup, 0, true, this, this);
 		//detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
         detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
         connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
@@ -1384,9 +1467,8 @@ void eWallet::askPassword () {
 	if (loginDialogDlg.isNull()) {
 		loginDialogDlg = new LoginDialog(!::dbManager->hasPassword (), this);
 		setCentralWidget(loginDialogDlg);
-		setFocus ();
-		focusNextChild();
 	}
+	loginDialogDlg->focus ();
 }
 
 void eWallet::about() {
